/*********************************************************
 * Copyright (C) 2009-2015 VMware, Inc. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation version 2.1 and no later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *********************************************************/

/*
 * hgfsClient.h
 *
 *    Provides a helper library for guest applications to access
 *    the HGFS file system.
 */

#ifndef _HGFS_HELPER_H_
#define _HGFS_HELPER_H_

#include "vm_basic_types.h"
#include "unicode.h"

Bool HgfsHlpr_QuerySharesDefaultRootPath(char **hgfsRootPath);
void HgfsHlpr_FreeSharesRootPath(char *hgfsRootPath);
#if defined(_WIN32)
Bool HgfsHlpr_ReadRegistryDefaultRootPath(char **hgfsRootPath);
#endif // _WIN32

#endif
